==> php82-nextcloud-28.0.2.tgz: share/nextcloud/apps/files_reminders/l10n/cs.js <==
OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "Připomínky souborů",
    "Reminder for {name}" : "Připomínka ohledně {name}",
    "View file" : "Zobrazit soubor",
    "View folder" : "Zobrazit složku",
    "Set file reminders" : "Nastavit připomínky souborů",
    "**📣 File reminders**\n\nSet file reminders." : "**📣 Připomínky souborů**\n\nNastavte připomínky souborů.",
    "We will remind you of this file" : "Připomeneme vám tento soubor",
    "Please choose a valid date & time" : "Zvolte platný datum a čas",
    "Cancel" : "Storno",
    "Set reminder" : "Nastavit připomínku",
    "Set reminder for \"{fileName}\"" : "Nastavit připomínku pro „{fileName}",
    "Set reminder at custom date & time" : "Nastavit připomínku na uživatelsky určené datum a čas",
    "Clear reminder" : "Vyčistit připomínku",
    "Reminder set for \"{fileName}\"" : "Nastavena připomínka ohledně „{fileName}“",
    "Failed to set reminder" : "Připomínku se nepodařilo nastavit",
    "Set custom reminder" : "Nastavit uživatelsky určenou připomínku",
    "Later today" : "Později dnes",
    "Set reminder for later today" : "Nastavit připomínku na později dnes",
    "Tomorrow" : "Zítra",
    "Set reminder for tomorrow" : "Nastavit připomínku na zítra",
    "This weekend" : "Tento víkend",
    "Set reminder for this weekend" : "Nastavit připomínku na tento víkend",
    "Next week" : "Příští týden",
    "Set reminder for next week" : "Nastavit připomínku pro příští týden",
    "Back" : "Zpět",
    "Reminder cleared" : "Připomínka vyčištěna",
    "Failed to clear reminder" : "Připomínku se nepodařilo vyčistit",
    "Failed to load reminder" : "Připomínku se nepodařilo načíst"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");

==> php82-nextcloud-30.0.2.tgz: share/nextcloud/apps/files_reminders/l10n/cs.js <==
OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "Připomínky souborů",
    "Reminder for {name}" : "Připomínka ohledně {name}",
    "View file" : "Zobrazit soubor",
    "View folder" : "Zobrazit složku",
    "Set file reminders" : "Nastavit připomínky souborů",
    "**📣 File reminders**\n\nSet file reminders." : "**📣 Připomínky souborů**\n\nNastavte připomínky souborů.",
    "We will remind you of this file" : "Připomeneme vám tento soubor",
    "Please choose a valid date & time" : "Zvolte platný datum a čas",
    "Cancel" : "Storno",
    "Clear reminder" : "Vyčistit připomínku",
    "Set reminder" : "Nastavit připomínku",
    "Set reminder for \"{fileName}\"" : "Nastavit připomínku pro „{fileName}",
    "Set reminder at custom date & time" : "Nastavit připomínku na uživatelsky určené datum a čas",
    "Reminder set for \"{fileName}\"" : "Nastavena připomínka ohledně „{fileName}“",
    "Failed to set reminder" : "Připomínku se nepodařilo nastavit",
    "Reminder cleared for \"{fileName}\"" : "Připomínka ohledně „{fileName}“ vyčištěna",
    "Failed to clear reminder" : "Připomínku se nepodařilo vyčistit",
    "Reminder set" : "Nastavit připomínku",
    "Set custom reminder" : "Nastavit uživatelsky určenou připomínku",
    "Later today" : "Později dnes",
    "Set reminder for later today" : "Nastavit připomínku na později dnes",
    "Tomorrow" : "Zítra",
    "Set reminder for tomorrow" : "Nastavit připomínku na zítra",
    "This weekend" : "Tento víkend",
    "Set reminder for this weekend" : "Nastavit připomínku na tento víkend",
    "Next week" : "Příští týden",
    "Set reminder for next week" : "Nastavit připomínku pro příští týden"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
